@@ -202,6 +202,7 @@ void control_o_loop( int key )
     case 'D': Window_vector::remove_duplicate_lines(); break;
     case 'E': Window_vector::remove_duplicate_lines( true ); break;
     case 'L': Window_vector::change_case( false ); break;
+    case 'N': Window_vector::change_buffer_name(); break;
     case 'R': werase( stdscr ); wrefresh( stdscr ); repaint(); break;
     case 'S': Window_vector::split_window(); break;
     case 'U': Window_vector::change_case( true ); break;
@@ -323,7 +324,8 @@ bool Screen::init()
 const std::string & Screen::clock_string() throw() { return _clock_string; }
 
 
-void Screen::clock_handler( const int sig ) throw()	// updates the clock
+// updates the clock
+extern "C" void Screen::clock_handler( int sig ) throw()
   {
   time_t dummy = time( 0 ); struct tm *t = localtime( &dummy );
   if( t )
